@@ -37,10 +37,6 @@
 #include "SaveLoad/ksirkgamexmlloader.h"
 #include "Sprites/animspritesgroup.h"
 #include "Dialogs/kplayersetupwidget.h"
-#if HAVE_JABBER_SUPPORT
-#include "Dialogs/jabbergameui.h"
-#include "Jabber/kmessagejabber.h"
-#endif
 
 #define USE_UNSTABLE_LIBKDEGAMESPRIVATE_API
 #include <libkdegamesprivate/kgame/kmessageserver.h>
@@ -396,28 +392,12 @@ void KGameWindow::slotArena(bool isCheck)
   }
 }
 
-#if HAVE_JABBER_SUPPORT
-void KGameWindow::slotJabberGame()
-{
-  m_jabberGameWidget->init(m_automaton);
-  m_jabberGameWidget->setPreviousGuiIndex(m_centralWidget->currentIndex());
-  m_centralWidget->setCurrentIndex(JABBERGAME_INDEX);
-}
-#endif
-
 void KGameWindow::slotNewGame()
 {
   //   qCDebug(KSIRK_LOG) << "Slot new game: posting event actionNewGame";
   actionNewGame(GameAutomaton::None);
 }
 
-#if HAVE_JABBER_SUPPORT
-void KGameWindow::slotNewJabberGame()
-{
-  actionNewGame(GameAutomaton::Jabber);
-}
-#endif
-
 void KGameWindow::slotNewSocketGame()
 {
   //   qCDebug(KSIRK_LOG) << "Slot new game: posting event actionNewGame";
@@ -458,7 +438,7 @@ void KGameWindow::slotSaveGame()
     }
     if (m_fileName.isEmpty())
     {
-      QString fileName = QFileDialog::getSaveFileName (this, i18nc("@title:window", "KsirK - Save Game"), QString(), "*.xml");
+      QString fileName = QFileDialog::getSaveFileName (this, i18nc("@title:window", "Save Game"), QString(), "*.xml");
       if ( fileName.isEmpty())
       {
         m_message->setMessageTimeout(3000);
@@ -822,7 +802,7 @@ void KGameWindow::slotDisableHelp(const QString & link)
   KsirkSettings::setHelpEnabled(false);
 }
 
-void KGameWindow::slotArmiesNumberChanged(int checked)
+void KGameWindow::slotArmiesNumberChanged(bool checked)
 {
   qCDebug(KSIRK_LOG) << checked;
   KsirkSettings::setShowArmiesNumbers(checked);
@@ -866,37 +846,8 @@ void KGameWindow::slotNewGameNext()
   qCDebug(KSIRK_LOG);
   m_automaton->newGameNext();
   m_reinitializingGame = false;
-  
-#if HAVE_JABBER_SUPPORT
-  if (m_automaton->networkGameType()==GameAutomaton::Jabber && m_jabberClient && m_jabberClient->isConnected())
-  {
-    sendGameInfoToJabber();
-  }
-#endif
 }
 
-// void KGameWindow::slotNewGameOK(unsigned int nbPlayers, const QString& skin, unsigned int nbNetworkPlayers, bool useGoals)
-// {
-//   qCDebug(KSIRK_LOG) << nbPlayers << skin << nbNetworkPlayers << useGoals;
-//   m_automaton->setGameStatus(KGame::End);
-//   m_reinitializingGame = true;
-//   m_automaton->removeAllPlayers();
-// 
-//   showMap();
-//   m_newPlayersNumber = nbPlayers;
-//   m_automaton->setUseGoals(useGoals);
-//   m_automaton->state(GameLogic::GameAutomaton::INIT);
-//   m_automaton->savedState(GameLogic::GameAutomaton::INVALID);
-//   m_automaton->setNetworkPlayersNumber(m_automaton->networkGameType()==GameAutomaton::None?0:nbNetworkPlayers);
-//   m_automaton->finishSetupPlayersNumberAndSkin(skin, nbPlayers);
-//   m_reinitializingGame = false;
-// 
-//   if (m_automaton->networkGameType()==GameAutomaton::Jabber && m_jabberClient && m_jabberClient->isConnected())
-//   {
-//     sendGameInfoToJabber();
-//   }
-// }
-
 void KGameWindow::slotNewGameKO()
 {
   qCDebug(KSIRK_LOG) << m_stateBeforeNewGame << m_stackWidgetBeforeNewGame;
@@ -905,240 +856,6 @@ void KGameWindow::slotNewGameKO()
   m_automaton->setGameStatus(KGame::Run);
 }
 
-#if HAVE_JABBER_SUPPORT
-void KGameWindow::slotConnected()
-{
-  qCDebug(KSIRK_LOG) << "Connected to Jabber server.";
-  
-  qCDebug(KSIRK_LOG) << "Requesting roster...";
-  m_jabberClient->requestRoster ();
-}
-
-void KGameWindow::slotRosterRequestFinished ( bool success )
-{
-  qCDebug(KSIRK_LOG) << success;
-  
-  /* Since we are online now, set initial presence. Don't do this
-  * before the roster request or we will receive presence
-  * information before we have updated our roster with actual
-  * contacts from the server! (Iris won't forward presence
-  * information in that case either). */
-  qCDebug(KSIRK_LOG) << "Setting initial presence...";
-  setPresence ( m_initialPresence );
-}
-
-void KGameWindow::slotCSDisconnected ()
-{
-  qCDebug(KSIRK_LOG) << "Disconnected from Jabber server.";
-  
-  /*
-  * We should delete the JabberClient instance here,
-  * but timers etc prevent us from doing so. Iris does
-  * not like to be deleted from a slot.
-  */
-
-  /* It seems that we don't get offline notifications when going offline
-  * with the protocol, so clear all resources manually. */
-//   resourcePool()->clear();
-  
-}
-
-void KGameWindow::slotReceivedMessage (const XMPP::Message & message)
-{
-  qCDebug(KSIRK_LOG) << "New " << message.type() << " message from " << message.from().full () << ": " << message.body();
-
-  QString body = message.body();
-  QString nick = message.from().full();
-
-  if ( message.type() == "groupchat" )
-  {
-    qCDebug(KSIRK_LOG) << "my jid:" << m_groupchatRoom+'@'+m_groupchatHost+'/'+m_groupchatNick;
-    XMPP::Jid jid ( message.from().domain() );
-    if (body.startsWith(QLatin1String("I'm starting a game with skin"))
-      && m_presents.contains(message.from().full ())
-      && message.from().full() != m_groupchatRoom+'@'+m_groupchatHost+'/'+m_groupchatNick)
-    {
-      qCDebug(KSIRK_LOG) << "start game message";
-      QRegExp rxlen("I'm starting a game with skin '([^']*)' and '(\\d+)' players");
-//       int pos = rxlen.indexIn(body);
-      QString skin = rxlen.cap(1); // "189"
-      int nbPlayers = rxlen.cap(2).toInt();  // "cm"
-      qCDebug(KSIRK_LOG) << "emiting newJabberGame" << nick << nbPlayers << skin;
-      emit newJabberGame(nick, nbPlayers, skin);
-    }
-    else if (body.startsWith(QLatin1String("Who propose online KsirK games here?")))
-    {
-      qCDebug(KSIRK_LOG) << "online games question" << m_automaton->stateName();
-      if (m_automaton->startingGame())
-      {
-        sendGameInfoToJabber();
-      }
-    }
-  }
-  else if ( message.type() == "ksirkgame" )
-  {
-    XMPP::Jid jid ( message.from() );
-    if (body == "connect")
-    {
-      qCDebug(KSIRK_LOG) << "received connect from" << jid.full();
-      KMessageJabber* messageIO = new KMessageJabber(jid.full(), m_jabberClient, this);
-      if (m_automaton->messageServer())
-      {
-        m_automaton->messageServer()->addClient(messageIO);
-      }
-    }
-    else
-    {
-      qCDebug(KSIRK_LOG) << "non connect ksirkgame message";
-    }
-  }
-}
-void KGameWindow::slotHandleTLSWarning (QCA::TLS::IdentityResult identityResult, QCA::Validity validityResult )
-{
-  qCDebug(KSIRK_LOG) << "Handling TLS warning..." << identityResult << validityResult;
-}
-
-void KGameWindow::slotClientError ( JabberClient::ErrorCode errorCode )
-{
-  qCDebug(KSIRK_LOG) << "Handling client error...";
-
-  switch ( errorCode )
-  {
-    case JabberClient::NoTLS:
-    default:
-#if 0 //QT5
-      KMessageBox::queuedMessageBox ( 0, KMessageBox::Error,
-                                                                                i18n ("An encrypted connection with the Jabber server could not be established."),
-                                                                                i18n ("Jabber Connection Error"));
-//                                                                                 disconnect ( 0/*Kopete::Account::Manual*/ );
-#endif
-                                                                                break;
-                                            }
-}
-
-void KGameWindow::slotCSError ( int error )
-{
-  qCDebug(KSIRK_LOG) << "Error in stream signalled.";
-  
-  if ( ( error == XMPP::ClientStream::ErrAuth )
-    && ( m_jabberClient->clientStream()->errorCondition () == XMPP::ClientStream::NotAuthorized ) )
-  {
-    qCDebug(KSIRK_LOG) << "Incorrect password, retrying.";
-//     disconnect(/*Kopete::Account::BadPassword*/0);
-  }
-  else
-  {
-//     int errorClass =  0;
-    
-    qCDebug(KSIRK_LOG) << "Disconnecting.";
-    
-    // display message to user
-//     if(!m_removing) //when removing the account, connection errors are normal.
-//       handleStreamError (error, m_jabberClient->clientStream()->errorCondition (), m_jabberClient->clientConnector()->errorCode (), server (), errorClass, m_jabberClient->clientStream()->errorText());
-//     
-//     disconnect ( errorClass );
-    
-    /*  slotCSDisconnected  will not be called*/
-//     resourcePool()->clear();
-  }
-  
-}
-
-void KGameWindow::slotClientDebugMessage ( const QString &msg )
-{
-  qCDebug(KSIRK_LOG) << msg;
-}
-
-void KGameWindow::slotGroupChatJoined (const XMPP::Jid & jid)
-{
-  qCDebug(KSIRK_LOG) << "Joined groupchat " << jid.full ();
-  
-  /*    <message type="chat" to="kleag@localhost" id="aabca" >
-  <body>hello</body>
-  </message>*/
-  XMPP::Message message(QString(m_groupchatRoom+'@'+m_groupchatHost));
-  message.setType("groupchat");
-  message.setId(QUuid::createUuid().toString().remove('{').remove('}').remove('-'));
-  message.setBody("Hello, I'm a KsirK Game");
-  m_jabberClient->sendMessage(message);
-
-  askForJabberGames();
-}
-
-void KGameWindow::slotGroupChatLeft (const XMPP::Jid & jid)
-{
-  qCDebug(KSIRK_LOG) << "Left groupchat " << jid.full ();
-}
-
-void KGameWindow::slotGroupChatPresence (const XMPP::Jid & jid, const XMPP::Status & status)
-{
-  qCDebug(KSIRK_LOG) << "Received groupchat presence for room " << jid.full() << status.isAvailable();
-  
-  if (status.isAvailable())
-  {
-    XMPP::Message message(jid);
-    message.setType("ksirkgame");
-    message.setId(QUuid::createUuid().toString().remove('{').remove('}').remove('-'));
-    message.setBody(QString("Hello, ")+jid.full());
-    m_jabberClient->sendMessage(message);
-    m_presents.insert(jid.full());
-  }
-  else
-  {
-    m_presents.remove(jid.full());
-  }
-}
-
-void KGameWindow::slotGroupChatError (const XMPP::Jid &jid, int error, const QString &reason)
-{
-  qCDebug(KSIRK_LOG) << "Group chat error - room " << jid.full () << " had error " << error << " (" << reason << ")";
-  
-  switch (error)
-  {
-    case JabberClient::InvalidPasswordForMUC:
-    {
-      KPasswordDialog dlg(nullptr);
-      dlg.setPrompt(i18n("A password is required to join the room %1.", jid.node()));
-      if (dlg.exec() == KPasswordDialog::Accepted)
-        m_jabberClient->joinGroupChat(jid.domain(), jid.node(), jid.resource(), dlg.password());
-    }
-    break;
-    
-    case JabberClient::NicknameConflict:
-    {
-      bool ok;
-      QString nickname = QInputDialog::getText(this, i18n("Error trying to join %1: nickname %2 is already in use", jid.node(), jid.resource()), i18n("Provide your nickname"), QLineEdit::Normal, QString(), &ok);
-      if (ok)
-      {
-        m_jabberClient->joinGroupChat(jid.domain(), jid.node(), nickname);
-      }
-    }
-    break;
-    
-    case JabberClient::BannedFromThisMUC:
-      //QT5 KMessageBox::queuedMessageBox ( 0, KMessageBox::Error, i18n ("You cannot join the room %1 because you have been banned", jid.node()), i18n ("Jabber Group Chat") );
-      break;
-                                      
-    case JabberClient::MaxUsersReachedForThisMuc:
-      //QT5 KMessageBox::queuedMessageBox ( 0, KMessageBox::Error, i18n ("You cannot join the room %1 because the maximum number of users has been reached", jid.node()), i18n ("Jabber Group Chat") );
-      break;
-                                      
-    default:
-    {
-      QString detailedReason = reason.isEmpty () ? i18n ( "No reason given by the server" ) : reason;
-      
-      //QT5 KMessageBox::queuedMessageBox ( 0, KMessageBox::Error, i18n ("There was an error processing your request for groupchat %1. (Reason: %2, Code %3)", jid.full (), detailedReason, error ), i18n ("Jabber Group Chat") );
-    }
-  }
-}
-
-void KGameWindow::slotJabberGameCanceled(int previousIndex)
-{
-  qCDebug(KSIRK_LOG) << previousIndex;
-  m_centralWidget->setCurrentIndex(previousIndex);
-}
-#endif
-
 void KGameWindow::slotExit()
 {
 //   hide();
